﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows.Input;
using Abt.Controls.SciChart;
using Abt.Controls.SciChart.Visuals.Axes;
using WpfApplication15.Annotations;

namespace WpfApplication15
{
    public class MainViewModel : INotifyPropertyChanged
    {
        private readonly ObservableCollection<AxisViewModel> _yAxisViewModels = new ObservableCollection<AxisViewModel>();

        // ActionCommand is included in SciChart, but any MVVM framework ICommand implementation will do
        private readonly ActionCommand _addAxisCommand;
        private readonly ActionCommand _removeAxisCommand;

        public event PropertyChangedEventHandler PropertyChanged;

        public MainViewModel()
        {
            _addAxisCommand = new ActionCommand(OnAddAxis);
            _removeAxisCommand = new ActionCommand(OnRemoveAxis, CanRemoveAxis);
        }        

        public ObservableCollection<AxisViewModel> YAxesViewModels
        {
            get { return _yAxisViewModels; }
        }

        public ActionCommand AddAxisCommand
        {
            get { return _addAxisCommand; }
        }

        public ActionCommand RemoveAxisCommand
        {
            get { return _removeAxisCommand; }
        }

        private void OnAddAxis()
        {
            Random rand = new Random();
            var min = rand.Next(0, 10)*10;
            var max = min + rand.Next(1, 10)*10;

            var yAxisViewModel = new AxisViewModel()
            {
                AutoRange = AutoRange.Once,
                Title = "YAxis " + (YAxesViewModels.Count + 1),
                VisibleRange = new DoubleRange(min, max),
                AxisId = "Axis" + YAxesViewModels.Count
            };
            YAxesViewModels.Add(yAxisViewModel);
            RemoveAxisCommand.RaiseCanExecuteChanged();
        }

        private bool CanRemoveAxis()
        {
            return YAxesViewModels.Count > 0;
        }

        private void OnRemoveAxis()
        {
            YAxesViewModels.RemoveAt(YAxesViewModels.Count-1);
            RemoveAxisCommand.RaiseCanExecuteChanged();
        }
            
        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
